@@ -29,6 +29,8 @@
 
 'common helpers for unilint code and plugins'
 
+from __future__ import absolute_import, print_function, unicode_literals
+import sys
 import os
 import re
 import logging
@@ -101,12 +103,12 @@ def run_shell_command(cmd,
                 line = proc.stdout.readline().decode('UTF-8')
                 if line != '':
                     if verbose:
-                        print(line),
+                        sys.stdout.write(line)
                         stdout_buf.append(line)
                 line2 = proc.stderr.readline().decode('UTF-8')
                 if line2 != '':
                     if verbose:
-                        print(line2),
+                        sys.stdout.write(line2)
                         stderr_buf.append(line2)
                 if ((not line and not line2) or proc.returncode is not None):
                     break
