@@ -27,7 +27,9 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from __future__ import print_function
+'plugin for cppcheck'
+
+from __future__ import absolute_import, print_function, unicode_literals
 import re
 from unilint.cpp_source_plugin import AbstractCppPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
@@ -44,6 +46,7 @@ _IGNORED_PREFIXES = [
 
 
 class CppcheckPlugin(AbstractCppPlugin):
+    'plugin for cppcheck'
 
     def __init__(self, shell_function):
         super(CppcheckPlugin, self).__init__(shell_function)
@@ -64,6 +67,7 @@ class CppcheckPlugin(AbstractCppPlugin):
             "ERROR Cannot find cppcheck, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
+        'runs the tool and processes the output'
         if not 'cpp-file' in type_categories:
             return None
 
@@ -98,10 +102,10 @@ class CppcheckPlugin(AbstractCppPlugin):
             print(output)
             return None
         else:
-            return self.parse(output)
+            return (self.parse(output), None)
 
     def parse(self, output):
-        '''example output'''
+        'creates an issue from an output line'
         issues = []
         for line in output.splitlines():
             ignore = False
