@@ -27,8 +27,9 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from __future__ import print_function
-import os
+'pep8 plugin'
+
+from __future__ import absolute_import, print_function, unicode_literals
 from unilint.python_source_plugin import AbstractPythonPlugin
 from unilint.unilint_plugin import UnilintPluginInitException
 from unilint.unilint_main import LEVEL_WARNING, LEVEL_STYLE, LEVELS
@@ -36,6 +37,7 @@ from unilint.issue import Issue
 
 
 class Pep8Plugin(AbstractPythonPlugin):
+    'pep8 plugin'
 
     def __init__(self, shell_function):
         super(Pep8Plugin, self).__init__(shell_function)
@@ -56,6 +58,7 @@ class Pep8Plugin(AbstractPythonPlugin):
             "ERROR Cannot find pep8, install via apt or pip\n%s" % message)
 
     def check_resource(self, options, path, type_categories):
+        'runs the tool and processes the output'
         if not 'python-src' in type_categories and \
                 not 'script' in type_categories and \
                 not 'python-module' in type_categories:
@@ -84,15 +87,16 @@ class Pep8Plugin(AbstractPythonPlugin):
         _, output, _ = self.shell_cmd(cmd,
                                       shell=True,
                                       us_env=True)
-
         if options.raw:
             print(output)
             return None
         else:
-            basepath = os.path.dirname(path)
-            return self.parse(output, basepath)
+            return (self.parse(output), None)
 
-    def parse(self, output, basepath):
+    def parse(self, output):
+        'creates an issue from an output line'
+        # Example output:
+        # /tmp/foo.py:4:1: E302 expected 2 blank lines, found 1
         issues = []
         for line in output.splitlines():
             if line.strip() == '':
@@ -105,7 +109,7 @@ class Pep8Plugin(AbstractPythonPlugin):
             if category.startswith('W'):
                 severity = "style"
 
-            issue = Issue(path=os.path.join(basepath, tokens[0]),
+            issue = Issue(path=tokens[0],
                           message=message,
                           checker_id=self.get_id(),
                           line_number_start=tokens[1],
