@@ -187,6 +187,8 @@ def remove_duplicates(issues):
             sameline_issues = []
             lastline = int(issue.line_number_start or -1)
             is_likely_duplicate = False
+        if issue.line_number_start and int(issue.line_number_start) >= 0:
+            lastline = int(issue.line_number_start)
 
         if is_likely_duplicate:
             # check whether new issue is a duplicate
